@@ -20,6 +20,7 @@
 #include "JudyHS.h"
 #endif
 
+#include "IntSet.h"
 #include "Wikidiff2.h"
 #include "Word.h"
 #include "textutil.h"
@@ -31,8 +32,8 @@
 #define WIKIDIFF2_CHANGE_THRESHOLD_DEFAULT		"0.2"
 // Default value for INI setting wikidiff2.moved_line_threshold
 #define WIKIDIFF2_MOVED_LINE_THRESHOLD_DEFAULT	"0.4"
-// Default value for INI setting wikidiff2.moved_paragraph_detection_cutoff_mobile
-#define WIKIDIFF2_MOVED_PARAGRAPH_DETECTION_CUTOFF_MOBILE "30"
+// Default value for INI setting wikidiff2.moved_paragraph_detection_cutoff
+#define WIKIDIFF2_MOVED_PARAGRAPH_DETECTION_CUTOFF_DEFAULT "100"
 
 #ifdef DEBUG_MOVED_LINES
 inline void debugLog(const char *fmt, ...) {
@@ -151,7 +152,6 @@ class DiffEngine
 #endif
 
 		// Sets
-		typedef std::set<int, std::less<int>, WD2_ALLOCATOR<int> > IntSet;
 #ifdef USE_JUDY
 		typedef JudySet ValueSet;
 #else
@@ -233,12 +233,12 @@ inline int movedParagraphDetectionCutoff()
 {
 #ifdef HHVM_BUILD_DSO
 	// HHVM module
-	HPHP::Variant value(WIKIDIFF2_MOVED_PARAGRAPH_DETECTION_CUTOFF_MOBILE);
-	HPHP::IniSetting::Get(std::string("wikidiff2.moved_paragraph_detection_cutoff_mobile"), value);
+	HPHP::Variant value(WIKIDIFF2_MOVED_PARAGRAPH_DETECTION_CUTOFF_DEFAULT);
+	HPHP::IniSetting::Get(std::string("wikidiff2.moved_paragraph_detection_cutoff"), value);
 	return value.toInt32();
 #else
 	// Zend module
-	int ret = INI_INT("wikidiff2.moved_paragraph_detection_cutoff_mobile");
+	int ret = INI_INT("wikidiff2.moved_paragraph_detection_cutoff");
 	return ret;
 #endif //HHVM_BUILD_DSO
 }
@@ -518,7 +518,7 @@ int DiffEngine<T>::diag (int xoff, int xlim, int yoff, int ylim, int nchunks,
 			int k = 0;
 
 			for (y = pMatches->begin(); y != pMatches->end(); ++y) {
-				if (!in_seq.count(*y)) {
+				if (!in_seq.contains(*y)) {
 					k = lcs_pos(*y);
 					assert(k > 0);
 					copy(ymids.begin() + (k-1) * nchunks, ymids.begin() + k * nchunks,
@@ -535,7 +535,7 @@ int DiffEngine<T>::diag (int xoff, int xlim, int yoff, int ylim, int nchunks,
 					in_seq.erase(seq[k]);
 					seq[k] = *y;
 					in_seq.insert(*y);
-				} else if (!in_seq.count(*y)) {
+				} else if (!in_seq.contains(*y)) {
 					k = lcs_pos(*y);
 					assert(k > 0);
 					copy(ymids.begin() + (k-1) * nchunks, ymids.begin() + k * nchunks,
