@@ -1,6 +1,6 @@
 <?hh
 <<__Native>>
-function wikidiff2_do_diff(string $text1, string $text2, int $numContextLines, int $maxMovedLines = 25): string;
+function wikidiff2_do_diff(string $text1, string $text2, int $numContextLines): string;
 
 <<__Native>>
 function wikidiff2_inline_diff(string $text1, string $text2, int $numContextLines): string;
